+
diff --git a/components/lib/datatable/style/DataTableStyle.js b/components/lib/datatable/style/DataTableStyle.js
index b74dd32bb5..cdd436649a 100644
--- a/components/lib/datatable/style/DataTableStyle.js
+++ b/components/lib/datatable/style/DataTableStyle.js
@@ -595,7 +595,7 @@ const classes = {
'p-datatable-lg': props.size === 'large'
}
],
- overlay: 'p-datatable-mask p-component-overlay',
+ mask: 'p-datatable-mask p-component-overlay',
loadingIcon: 'p-datatable-loading-icon',
header: 'p-datatable-header',
pcPaginator: ({ position }) => 'p-datatable-paginator-' + position,
diff --git a/components/lib/datepicker/DatePicker.d.ts b/components/lib/datepicker/DatePicker.d.ts
index ae2bd1799c..4f55797c7b 100755
--- a/components/lib/datepicker/DatePicker.d.ts
+++ b/components/lib/datepicker/DatePicker.d.ts
@@ -143,6 +143,10 @@ export interface DatePickerPassThroughOptions {
* Used to pass attributes to the dropdown's DOM element.
*/
dropdown?: DatePickerPassThroughOptionType;
+ /**
+ * Used to pass attributes to the dropdown icon's DOM element.
+ */
+ dropdownIcon?: DatePickerPassThroughOptionType;
/**
* Used to pass attributes to the panel's DOM element.
*/
diff --git a/components/lib/inputnumber/BaseInputNumber.vue b/components/lib/inputnumber/BaseInputNumber.vue
index 1d123e0b5b..bdd5090c13 100644
--- a/components/lib/inputnumber/BaseInputNumber.vue
+++ b/components/lib/inputnumber/BaseInputNumber.vue
@@ -34,10 +34,18 @@ export default {
type: String,
default: undefined
},
+ incrementIcon: {
+ type: String,
+ default: undefined
+ },
decrementButtonIcon: {
type: String,
default: undefined
},
+ decrementIcon: {
+ type: String,
+ default: undefined
+ },
locale: {
type: String,
default: undefined
diff --git a/components/lib/inputnumber/InputNumber.vue b/components/lib/inputnumber/InputNumber.vue
index 2880c4a4cf..02343e2b1f 100755
--- a/components/lib/inputnumber/InputNumber.vue
+++ b/components/lib/inputnumber/InputNumber.vue
@@ -31,33 +31,34 @@
+
diff --git a/components/lib/inputnumber/InputNumber.d.ts b/components/lib/inputnumber/InputNumber.d.ts
index 9721d2e19c..b7b2078dc3 100755
--- a/components/lib/inputnumber/InputNumber.d.ts
+++ b/components/lib/inputnumber/InputNumber.d.ts
@@ -113,10 +113,18 @@ export interface InputNumberPassThroughOptions {
* Used to pass attributes to the increment button's DOM element.
*/
incrementButton?: InputNumberPassThroughOptionType;
+ /**
+ * Used to pass attributes to the increment icon's DOM element.
+ */
+ incrementIcon?: InputNumberPassThroughOptionType;
/**
* Used to pass attributes to the decrement button's DOM element.
*/
decrementButton?: InputNumberPassThroughOptionType;
+ /**
+ * Used to pass attributes to the decrement icon's DOM element.
+ */
+ decrementIcon?: InputNumberPassThroughOptionType;
/**
* Used to manage all lifecycle hooks.
* @see {@link BaseComponent.ComponentHooks}
@@ -209,15 +217,23 @@ export interface InputNumberProps {
*/
decrementButtonClass?: string | undefined;
/**
* Style class of the increment button.
* @deprecated since v3.27.0. Use 'incrementbuttonicon' slot.
*/
incrementButtonIcon?: string | undefined;
/**
- * Style class of the decrement button.
- * @deprecated since v3.27.0. Use 'decrementbuttonicon' slot.
+ * Style class of the increment icon.
+ */
+ incrementIcon?: string | undefined;
+ /**
+ * Style class of the decrement icon.
+ * @deprecated since v4.0. Use 'decrementIcon'.
*/
decrementButtonIcon?: string | undefined;
+ /**
+ * Style class of the decrement icon.
+ */
+ decrementIcon?: string | undefined;
/**
* Locale to be used in formatting.
*/
@@ -382,13 +398,23 @@ export interface InputNumberSlots {
listeners: InputNumberButtonListeners;
}): VNode[];
/**
* Custom increment button icon template.
*/
incrementbuttonicon(): VNode[];
/**
- * Custom decrement button icon template.
+ * Custom increment icon template.
+ */
+ incrementicon(): VNode[];
+ /**
+ * @deprecated since v4.0. Use 'decrementicon' slot.
+ * Custom decrement icon template.
*/
decrementbuttonicon(): VNode[];
+ /**
+ * Custom decrement icon template.
+ */
+ decrementicon(): VNode[];
}
/**
@@ -209,15 +217,23 @@ export interface InputNumberProps {
decrementButtonClass?: string | undefined;
/**
- * Style class of the increment button.
- * @deprecated since v3.27.0. Use 'incrementbuttonicon' slot.
+ * Style class of the increment icon.
+ * @deprecated since v4.0. Use 'incrementIcon'.
*/
incrementButtonIcon?: string | undefined;
@@ -382,13 +398,23 @@ export interface InputNumberSlots {
}): VNode[];
/**
- * Custom increment button icon template.
+ * @deprecated since v4.0. Use 'incrementicon' slot.
+ * Custom increment icon template.
*/
incrementbuttonicon(): VNode[];